@@ -425,22 +425,6 @@ EbErrorType svt_av1_verify_settings(SequenceControlSet *scs) {
         return_error = EB_ErrorBadParameter;
     }
 
-    // IntraBC
-    if (scs->intrabc_mode > 3 || scs->intrabc_mode < -1) {
-        SVT_ERROR("Instance %u: Invalid intraBC mode [0-3, -1 for default], your input: %i\n",
-                  channel_number + 1,
-                  scs->intrabc_mode);
-        return_error = EB_ErrorBadParameter;
-    }
-
-    if (scs->intrabc_mode > 0 && config->screen_content_mode != 1) {
-        SVT_ERROR(
-            "Instance %u: The intra BC feature is only available when screen_content_mode is set "
-            "to 1\n",
-            channel_number + 1);
-        return_error = EB_ErrorBadParameter;
-    }
-
     if (scs->static_config.enable_adaptive_quantization > 2) {
         SVT_ERROR(
             "Instance %u : Invalid enable_adaptive_quantization. enable_adaptive_quantization must "
