@@ -26,22 +26,15 @@
  ******************************************************************************/
 #include <cstdlib>
 #include <string>
+
 #include "gtest/gtest.h"
-// workaround to eliminate the compiling warning on linux
-// The macro will conflict with definition in gtest.h
-#ifdef __USE_GNU
-#undef __USE_GNU  // defined in EbThreads.h
-#endif
-#ifdef _GNU_SOURCE
-#undef _GNU_SOURCE  // defined in EbThreads.h
-#endif
-#include "EbDefinitions.h"
+#include "definitions.h"
 #include "aom_dsp_rtcd.h"
-#include "EbEncCdef.h"
+#include "enc_cdef.h"
 #include "util.h"
 #include "random.h"
-#include "EbUnitTestUtility.h"
-#include "EbUtility.h"
+#include "unit_test_utility.h"
+#include "utility.h"
 
 using svt_av1_test_tool::SVTRandom;
 using ::testing::make_tuple;
@@ -54,10 +47,17 @@ typedef void (*svt_cdef_filter_block_8xn_16_func)(
 
 static const svt_cdef_filter_block_8xn_16_func
     svt_cdef_filter_block_8xn_16_func_table[] = {
+#if defined(ARCH_X86_64)
         svt_cdef_filter_block_8xn_16_avx2,
 #if EN_AVX512_SUPPORT
         svt_cdef_filter_block_8xn_16_avx512
 #endif
+#endif
+
+#if defined(ARCH_AARCH64)
+            NULL,  // No C version, only applicable for avx2 and avx512
+#endif
+
 };
 using cdef_dir_param_t =
     ::testing::tuple<CdefFilterBlockFunc, CdefFilterBlockFunc, BlockSize, int,
@@ -98,7 +98,9 @@ class CDEFBlockTest : public ::testing::TestWithParam<cdef_dir_param_t> {
         bsize_ = TEST_GET_PARAM(2);
         boundary_ = TEST_GET_PARAM(3);
         bd_ = TEST_GET_PARAM(4);
-        svt_cdef_filter_block_8xn_16 = TEST_GET_PARAM(5);
+        if (TEST_GET_PARAM(5) != NULL) {
+            svt_cdef_filter_block_8xn_16 = TEST_GET_PARAM(5);
+        }
 
         memset(dst_ref_, 0, sizeof(dst_ref_));
         memset(dst_tst_, 0, sizeof(dst_tst_));
@@ -364,11 +366,13 @@ TEST_P(CDEFBlockTest, DISABLED_SpeedTest) {
     speed_cdef();
 }
 
+#if defined(ARCH_X86_64)
+
 // VS compiling for 32 bit targets does not support vector types in
 // structs as arguments, which makes the v256 type of the intrinsics
 // hard to support, so optimizations for this target are disabled.
 #if defined(_WIN64) || !defined(_MSC_VER) || defined(__clang__)
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     Cdef, CDEFBlockTest,
     ::testing::Combine(
         ::testing::Values(&svt_cdef_filter_block_avx2),
@@ -377,7 +381,7 @@ INSTANTIATE_TEST_CASE_P(
         ::testing::Range(0, 16), ::testing::Range(8, 13, 2),
         ::testing::ValuesIn(svt_cdef_filter_block_8xn_16_func_table)));
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     Cdef_sse4_1, CDEFBlockTest,
     ::testing::Combine(
         ::testing::Values(&svt_cdef_filter_block_avx2),
@@ -387,6 +391,19 @@ INSTANTIATE_TEST_CASE_P(
         ::testing::ValuesIn(svt_cdef_filter_block_8xn_16_func_table)));
 
 #endif  // defined(_WIN64) || !defined(_MSC_VER)
+#endif  // defined(ARCH_X86_64)
+
+#if defined(ARCH_AARCH64)
+INSTANTIATE_TEST_SUITE_P(
+    Cdef_neon, CDEFBlockTest,
+    ::testing::Combine(
+        ::testing::Values(&svt_cdef_filter_block_neon),
+        ::testing::Values(&svt_cdef_filter_block_c),
+        ::testing::Values(BLOCK_4X4, BLOCK_4X8, BLOCK_8X4, BLOCK_8X8),
+        ::testing::Range(0, 16), ::testing::Range(8, 13, 2),
+        ::testing::ValuesIn(svt_cdef_filter_block_8xn_16_func_table)));
+#endif  // defined(ARCH_AARCH64)
+
 using FindDirFunc = uint8_t (*)(const uint16_t *img, int stride, int32_t *var,
                                 int coeff_shift);
 using TestFindDirParam = ::testing::tuple<FindDirFunc, FindDirFunc>;
@@ -472,17 +489,30 @@ TEST_P(CDEFFindDirTest, MatchTest) {
     test_finddir();
 }
 
+#if defined(ARCH_X86_64)
+
 // VS compiling for 32 bit targets does not support vector types in
 // structs as arguments, which makes the v256 type of the intrinsics
 // hard to support, so optimizations for this target are disabled.
 #if defined(_WIN64) || !defined(_MSC_VER) || defined(__clang__)
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     Cdef, CDEFFindDirTest,
     ::testing::Values(
         make_tuple(&svt_aom_cdef_find_dir_sse4_1, &svt_aom_cdef_find_dir_c),
         make_tuple(&svt_aom_cdef_find_dir_avx2, &svt_aom_cdef_find_dir_c)));
 #endif  // defined(_WIN64) || !defined(_MSC_VER)
 
+#endif  // defined(ARCH_X86_64)
+
+#if defined(ARCH_AARCH64)
+
+INSTANTIATE_TEST_SUITE_P(
+    Cdef, CDEFFindDirTest,
+    ::testing::Values(make_tuple(&svt_aom_cdef_find_dir_neon,
+                                 &svt_aom_cdef_find_dir_c)));
+
+#endif
+
 using FindDirDualFunc = void (*)(const uint16_t *img1, const uint16_t *img2,
                                  int stride, int32_t *var1, int32_t *var2,
                                  int32_t coeff_shift, uint8_t *out1,
@@ -601,11 +631,13 @@ TEST_P(CDEFFindDirDualTest, MatchTest) {
     test_finddir();
 }
 
+#if defined(ARCH_X86_64)
+
 // VS compiling for 32 bit targets does not support vector types in
 // structs as arguments, which makes the v256 type of the intrinsics
 // hard to support, so optimizations for this target are disabled.
 #if defined(_WIN64) || !defined(_MSC_VER) || defined(__clang__)
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     Cdef, CDEFFindDirDualTest,
     ::testing::Values(make_tuple(&svt_aom_cdef_find_dir_dual_sse4_1,
                                  &svt_aom_cdef_find_dir_dual_c),
@@ -613,6 +645,18 @@ INSTANTIATE_TEST_CASE_P(
                                  &svt_aom_cdef_find_dir_dual_c)));
 
 #endif  // defined(_WIN64) || !defined(_MSC_VER)
+
+#endif  // defined(ARCH_X86_64)
+
+#if defined(ARCH_AARCH64)
+
+INSTANTIATE_TEST_SUITE_P(
+    Cdef, CDEFFindDirDualTest,
+    ::testing::Values(make_tuple(&svt_aom_cdef_find_dir_dual_neon,
+                                 &svt_aom_cdef_find_dir_dual_c)));
+
+#endif  // defined(ARCH_AARCH64)
+
 }  // namespace
 
 /**
@@ -657,6 +701,10 @@ TEST(CdefToolTest, CopyRectMatchTest) {
 
             svt_aom_copy_rect8_8bit_to_16bit_c(
                 dst_ref_, CDEF_BSTRIDE, src_, CDEF_BSTRIDE, vsize, hsize);
+
+#if defined(ARCH_X86_64)
+            // Test the SSE4.1 copy function
+            memset(dst_data_tst_, 0, sizeof(dst_data_tst_));
             svt_aom_copy_rect8_8bit_to_16bit_sse4_1(
                 dst_tst_, CDEF_BSTRIDE, src_, CDEF_BSTRIDE, vsize, hsize);
 
@@ -664,8 +712,8 @@ TEST(CdefToolTest, CopyRectMatchTest) {
                 for (int j = 0; j < hsize; ++j)
                     ASSERT_EQ(dst_ref_[i * CDEF_BSTRIDE + j],
                               dst_tst_[i * CDEF_BSTRIDE + j])
-                        << "copy_rect8_8bit_to_16bit failed with pos(" << i
-                        << " " << j << ")";
+                        << "copy_rect8_8bit_to_16bit_sse4_1 failed with pos("
+                        << i << " " << j << ")";
             }
 
             // Test the AVX2 copy function
@@ -676,9 +724,25 @@ TEST(CdefToolTest, CopyRectMatchTest) {
                 for (int j = 0; j < hsize; ++j)
                     ASSERT_EQ(dst_ref_[i * CDEF_BSTRIDE + j],
                               dst_tst_[i * CDEF_BSTRIDE + j])
-                        << "copy_rect8_8bit_to_16bit failed with pos(" << i
+                        << "copy_rect8_8bit_to_16bit_avx2 failed with pos(" << i
                         << " " << j << ")";
             }
+#endif  // defined(ARCH_X86_64)
+
+#if defined(ARCH_AARCH64)
+            // Test the NEON copy function
+            memset(dst_data_tst_, 0, sizeof(dst_data_tst_));
+            svt_aom_copy_rect8_8bit_to_16bit_neon(
+                dst_tst_, CDEF_BSTRIDE, src_, CDEF_BSTRIDE, vsize, hsize);
+
+            for (int i = 0; i < vsize; ++i) {
+                for (int j = 0; j < hsize; ++j)
+                    ASSERT_EQ(dst_ref_[i * CDEF_BSTRIDE + j],
+                              dst_tst_[i * CDEF_BSTRIDE + j])
+                        << "copy_rect8_8bit_to_16bit_neon failed with pos(" << i
+                        << " " << j << ")";
+            }
+#endif  // defined(ARCH_AARCH64)
         }
 }
 
@@ -750,6 +814,30 @@ TEST(CdefToolTest, ComputeCdefDistMatchTest) {
                                                         coeff_shift,
                                                         plane,
                                                         subsampling);
+
+#if defined(ARCH_AARCH64)
+
+                        // NEON
+                        const uint64_t neon_mse =
+                            svt_aom_compute_cdef_dist_16bit_neon(dst_data_,
+                                                                 stride,
+                                                                 src_data_,
+                                                                 dlist,
+                                                                 cdef_count,
+                                                                 test_bs[i],
+                                                                 coeff_shift,
+                                                                 plane,
+                                                                 subsampling);
+                        ASSERT_EQ(c_mse, neon_mse)
+                            << "svt_aom_compute_cdef_dist_16bit_sse4_1 failed "
+                            << "bitdepth: " << bd << " plane: " << plane
+                            << " BlockSize " << test_bs[i] << " loop: " << k;
+
+#endif  // if defined(ARCH_AARCH64)
+
+#if defined(ARCH_X86_64)
+
+                        // SSE4.1
                         const uint64_t sse_mse =
                             svt_aom_compute_cdef_dist_16bit_sse4_1(dst_data_,
                                                                    stride,
@@ -760,6 +848,12 @@ TEST(CdefToolTest, ComputeCdefDistMatchTest) {
                                                                    coeff_shift,
                                                                    plane,
                                                                    subsampling);
+                        ASSERT_EQ(c_mse, sse_mse)
+                            << "svt_aom_compute_cdef_dist_16bit_sse4_1 failed "
+                            << "bitdepth: " << bd << " plane: " << plane
+                            << " BlockSize " << test_bs[i] << " loop: " << k;
+
+                        // AVX2
                         const uint64_t avx_mse =
                             svt_aom_compute_cdef_dist_16bit_avx2(dst_data_,
                                                                  stride,
@@ -770,14 +864,12 @@ TEST(CdefToolTest, ComputeCdefDistMatchTest) {
                                                                  coeff_shift,
                                                                  plane,
                                                                  subsampling);
-                        ASSERT_EQ(c_mse, sse_mse)
-                            << "svt_aom_compute_cdef_dist_16bit_sse4_1 failed "
-                            << "bitdepth: " << bd << " plane: " << plane
-                            << " BlockSize " << test_bs[i] << " loop: " << k;
                         ASSERT_EQ(c_mse, avx_mse)
                             << "svt_aom_compute_cdef_dist_16bit_avx2 failed "
                             << "bitdepth: " << bd << " plane: " << plane
                             << " BlockSize " << test_bs[i] << " loop: " << k;
+
+#endif  // defined(ARCH_X86_64)
                     }
                 }
             }
@@ -802,7 +894,7 @@ TEST(CdefToolTest, ComputeCdefDist8bitMatchTest) {
 
         const int coeff_shift = bd - 8;
         SVTRandom skip_rnd_(0, 1);
-        for (int k = 0; k < 100; ++k) {
+        for (int k = 0; k < 10; ++k) {
             CdefList dlist[MI_SIZE_128X128 * MI_SIZE_128X128];
             int cdef_count = 0;
 
@@ -835,6 +927,9 @@ TEST(CdefToolTest, ComputeCdefDist8bitMatchTest) {
                                                              coeff_shift,
                                                              plane,
                                                              subsampling);
+
+#if defined(ARCH_X86_64)
+                        // SSE4.1
                         const uint64_t sse_mse =
                             svt_aom_compute_cdef_dist_8bit_sse4_1(dst_data_,
                                                                   stride,
@@ -845,6 +940,12 @@ TEST(CdefToolTest, ComputeCdefDist8bitMatchTest) {
                                                                   coeff_shift,
                                                                   plane,
                                                                   subsampling);
+                        ASSERT_EQ(c_mse, sse_mse)
+                            << "svt_aom_compute_cdef_dist_8bit_sse4_1 failed "
+                            << "bitdepth: " << bd << " plane: " << plane
+                            << " BlockSize " << test_bs[i] << " loop: " << k;
+
+                        // AVX2
                         const uint64_t avx_mse =
                             svt_aom_compute_cdef_dist_8bit_avx2(dst_data_,
                                                                 stride,
@@ -855,14 +956,29 @@ TEST(CdefToolTest, ComputeCdefDist8bitMatchTest) {
                                                                 coeff_shift,
                                                                 plane,
                                                                 subsampling);
-                        ASSERT_EQ(c_mse, sse_mse)
-                            << "svt_aom_compute_cdef_dist_8bit_sse4_1 failed "
-                            << "bitdepth: " << bd << " plane: " << plane
-                            << " BlockSize " << test_bs[i] << " loop: " << k;
                         ASSERT_EQ(c_mse, avx_mse)
                             << "svt_aom_compute_cdef_dist_8bit_avx2 failed "
                             << "bitdepth: " << bd << " plane: " << plane
                             << " BlockSize " << test_bs[i] << " loop: " << k;
+#endif  // defined(ARCH_X86_64)
+
+#if defined(ARCH_AARCH64)
+                        // NEON
+                        const uint64_t sse_mse =
+                            svt_aom_compute_cdef_dist_8bit_neon(dst_data_,
+                                                                stride,
+                                                                src_data_,
+                                                                dlist,
+                                                                cdef_count,
+                                                                test_bs[i],
+                                                                coeff_shift,
+                                                                plane,
+                                                                subsampling);
+                        ASSERT_EQ(c_mse, sse_mse)
+                            << "svt_aom_compute_cdef_dist_8bit_neon failed "
+                            << "bitdepth: " << bd << " plane: " << plane
+                            << " BlockSize " << test_bs[i] << " loop: " << k;
+#endif  // defined(ARCH_AARCH64)
                     }
                 }
             }
@@ -894,10 +1010,12 @@ typedef uint64_t (*svt_search_one_dual_func)(int *lev0, int *lev1,
                                              int start_gi, int end_gi);
 
 static const svt_search_one_dual_func search_one_dual_func_table[] = {
+#if defined(ARCH_X86_64)
     svt_search_one_dual_avx2,
 #if EN_AVX512_SUPPORT
     svt_search_one_dual_avx512
 #endif
+#endif
 };
 
 TEST(CdefToolTest, SearchOneDualMatchTest) {
