@@ -614,6 +614,9 @@ class sad_LoopTest : public ::testing::WithParamInterface<sad_LoopTestParam>,
 #if EN_AVX512_SUPPORT
             svt_sad_loop_kernel_avx512_intrin
 #endif
+#endif
+#ifdef ARCH_AARCH64
+                svt_sad_loop_kernel_neon
 #endif
         };
 
@@ -698,6 +701,9 @@ class sad_LoopTest : public ::testing::WithParamInterface<sad_LoopTestParam>,
 #if EN_AVX512_SUPPORT
             svt_sad_loop_kernel_avx512_intrin
 #endif
+#endif
+#ifdef ARCH_AARCH64
+                svt_sad_loop_kernel_neon
 #endif
         };
 
@@ -1067,6 +1073,7 @@ TEST_P(Allsad_CalculationTest, 8x8_16x16_Test_sse4_1) {
 TEST_P(Allsad_CalculationTest, 32x32_64x64_Test_sse4_1) {
     check_get_32x32_sad(svt_ext_eight_sad_calculation_32x32_64x64_sse4_1);
 }
+
 TEST_P(Allsad_CalculationTest, 32x32_64x64_Test_avx2) {
     check_get_32x32_sad(svt_ext_eight_sad_calculation_32x32_64x64_avx2);
 }
@@ -1079,6 +1086,10 @@ TEST_P(Allsad_CalculationTest, 8x8_16x16_Test_neon) {
     check_get_8x8_sad(svt_ext_all_sad_calculation_8x8_16x16_neon);
 }
 
+TEST_P(Allsad_CalculationTest, 32x32_64x64_Test_neon) {
+    check_get_32x32_sad(svt_ext_eight_sad_calculation_32x32_64x64_neon);
+}
+
 #endif
 
 INSTANTIATE_TEST_SUITE_P(
