@@ -12,12 +12,12 @@
 
 #include "aom_dsp_rtcd.h"
 #include "gtest/gtest.h"
-#include "EbTemporalFiltering.h"
+#include "temporal_filtering.h"
 #include "util.h"
 #include "random.h"
-#include "EbUtility.h"
-#include "EbUnitTestUtility.h"
-#include "EbUtility.h"
+#include "utility.h"
+#include "unit_test_utility.h"
+#include "utility.h"
 
 using svt_av1_test_tool::SVTRandom;
 
@@ -44,10 +44,10 @@ typedef void (*TemporalFilterFuncHbd)(
 
 #define MAX_STRIDE 256
 
-typedef std::tuple<TemporalFilterFunc, TemporalFilterFunc, int>
+typedef std::tuple<TemporalFilterFunc, TemporalFilterFunc>
     TemporalFilterWithParam;
 
-typedef std::tuple<TemporalFilterFuncHbd, TemporalFilterFuncHbd, int>
+typedef std::tuple<TemporalFilterFuncHbd, TemporalFilterFuncHbd>
     TemporalFilterWithParamHbd;
 
 static void TemporalFilterFillMeContexts(MeContext *cnt1, MeContext *cnt2) {
@@ -146,7 +146,6 @@ class TemporalFilterTestPlanewise
         setup_test_env();
         ref_func = TEST_GET_PARAM(0);
         tst_func = TEST_GET_PARAM(1);
-        use_fixed_point = TEST_GET_PARAM(2);
 
         for (int color_channel = 0; color_channel < COLOR_CHANNELS;
              color_channel++) {
@@ -255,7 +254,6 @@ class TemporalFilterTestPlanewise
 
     uint32_t stride[COLOR_CHANNELS];
     uint32_t stride_pred[COLOR_CHANNELS];
-    int use_fixed_point;
     float tf_decay_factor[COLOR_CHANNELS];
 };
 
@@ -460,24 +458,24 @@ TEST_P(TemporalFilterTestPlanewise, DISABLED_Speed) {
 
 #ifdef ARCH_X86_64
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AVX2_medium, TemporalFilterTestPlanewise,
     ::testing::Combine(
         ::testing::Values(svt_av1_apply_temporal_filter_planewise_medium_c),
-        ::testing::Values(svt_av1_apply_temporal_filter_planewise_medium_sse4_1,
-                          svt_av1_apply_temporal_filter_planewise_medium_avx2),
-        ::testing::Values(1)));
+        ::testing::Values(
+            svt_av1_apply_temporal_filter_planewise_medium_sse4_1,
+            svt_av1_apply_temporal_filter_planewise_medium_avx2)));
 
 #endif
 
 #ifdef ARCH_AARCH64
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     Neon_medium, TemporalFilterTestPlanewise,
     ::testing::Combine(
         ::testing::Values(svt_av1_apply_temporal_filter_planewise_medium_c),
-        ::testing::Values(svt_av1_apply_temporal_filter_planewise_medium_neon),
-        ::testing::Values(1)));
+        ::testing::Values(
+            svt_av1_apply_temporal_filter_planewise_medium_neon)));
 
 #endif
 class TemporalFilterTestPlanewiseHbd
@@ -598,7 +596,6 @@ class TemporalFilterTestPlanewiseHbd
     uint32_t stride[COLOR_CHANNELS];
     uint32_t stride_pred[COLOR_CHANNELS];
 
-    int use_fixed_point;
     float tf_decay_factor[COLOR_CHANNELS];
     uint32_t encoder_bit_depth;
 };
@@ -940,6 +937,7 @@ void TemporalFilterTestPlanewiseHbd::RunTest(int width, int height,
             encoder_bit_depth);
     }
 }
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(TemporalFilterTestPlanewiseHbd);
 
 TEST_P(TemporalFilterTestPlanewiseHbd, OperationCheck) {
     for (int height = 32; height <= 32; height = height * 2) {
@@ -955,14 +953,24 @@ TEST_P(TemporalFilterTestPlanewiseHbd, DISABLED_Speed) {
 
 #ifdef ARCH_X86_64
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AVX2_medium, TemporalFilterTestPlanewiseHbd,
     ::testing::Combine(
         ::testing::Values(svt_av1_apply_temporal_filter_planewise_medium_hbd_c),
         ::testing::Values(
             svt_av1_apply_temporal_filter_planewise_medium_hbd_sse4_1,
-            svt_av1_apply_temporal_filter_planewise_medium_hbd_avx2),
-        ::testing::Values(1)));
+            svt_av1_apply_temporal_filter_planewise_medium_hbd_avx2)));
+
+#endif
+
+#ifdef ARCH_AARCH64
+
+INSTANTIATE_TEST_SUITE_P(
+    NEON_medium, TemporalFilterTestPlanewiseHbd,
+    ::testing::Combine(
+        ::testing::Values(svt_av1_apply_temporal_filter_planewise_medium_hbd_c),
+        ::testing::Values(
+            svt_av1_apply_temporal_filter_planewise_medium_hbd_neon)));
 
 #endif
 
@@ -1334,6 +1342,36 @@ int32_t estimate_noise_fp16_avx2_wrapper(const uint16_t *src, int width,
 
 #endif
 
+#ifdef ARCH_AARCH64
+
+TEST_F(TemporalFilterTestApplyFilteringCentral, test_lbd_neon) {
+    for (int i = 0; i < 100; ++i) {
+        RunTest(false, svt_aom_apply_filtering_central_neon, NULL);
+    }
+}
+
+TEST_F(TemporalFilterTestApplyFilteringCentral, test_hbd_neon) {
+    for (int i = 0; i < 100; ++i) {
+        RunTest(true, NULL, svt_aom_apply_filtering_central_highbd_neon);
+    }
+}
+
+int32_t estimate_noise_fp16_c_wrapper(const uint16_t *src, int width,
+                                      int height, int stride, int bd) {
+    UNUSED(bd);
+    return svt_estimate_noise_fp16_c(
+        (const uint8_t *)src, width, height, stride);
+}
+
+int32_t estimate_noise_fp16_neon_wrapper(const uint16_t *src, int width,
+                                         int height, int stride, int bd) {
+    UNUSED(bd);
+    return svt_estimate_noise_fp16_neon(
+        (const uint8_t *)src, width, height, stride);
+}
+
+#endif  // ARCH_AARCH64
+
 typedef int32_t (*EstimateNoiseFuncFP)(const uint16_t *src, int width,
                                        int height, int stride, int bd);
 
@@ -1391,6 +1429,7 @@ class EstimateNoiseTestFP
     uint32_t encoder_bit_depth;
     int stride;
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(EstimateNoiseTestFP);
 
 TEST_P(EstimateNoiseTestFP, fixed_point) {
     RunTest();
@@ -1398,7 +1437,7 @@ TEST_P(EstimateNoiseTestFP, fixed_point) {
 
 #ifdef ARCH_X86_64
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AVX2_lbd, EstimateNoiseTestFP,
     ::testing::Combine(::testing::Values(estimate_noise_fp16_c_wrapper),
                        ::testing::Values(estimate_noise_fp16_avx2_wrapper),
@@ -1406,7 +1445,7 @@ INSTANTIATE_TEST_CASE_P(
                        ::testing::Values(2160, 1080, 720, 600, 480, 240),
                        ::testing::Values(8)));
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AVX2_hbd, EstimateNoiseTestFP,
     ::testing::Combine(::testing::Values(svt_estimate_noise_highbd_fp16_c),
                        ::testing::Values(svt_estimate_noise_highbd_fp16_avx2),
@@ -1416,6 +1455,18 @@ INSTANTIATE_TEST_CASE_P(
 
 #endif
 
+#ifdef ARCH_AARCH64
+
+INSTANTIATE_TEST_SUITE_P(
+    NEON_lbd, EstimateNoiseTestFP,
+    ::testing::Combine(::testing::Values(estimate_noise_fp16_c_wrapper),
+                       ::testing::Values(estimate_noise_fp16_neon_wrapper),
+                       ::testing::Values(3840, 1920, 1280, 800, 640, 360),
+                       ::testing::Values(2160, 1080, 720, 600, 480, 240),
+                       ::testing::Values(8)));
+
+#endif
+
 typedef double (*EstimateNoiseFuncDbl)(const uint16_t *src, int width,
                                        int height, int stride, int bd);
 
