@@ -120,6 +120,8 @@ class MseTest : public ::testing::TestWithParam<TestMseParam> {
     MSE_NXM_FUNC mse_ref_;
 };
 
+#ifdef ARCH_X86_64
+
 TEST_P(MseTest, MatchTest) {
     run_match_test();
 };
@@ -134,6 +136,8 @@ INSTANTIATE_TEST_SUITE_P(
         TestMseParam(16, 16, &svt_aom_mse16x16_sse2, &svt_aom_mse16x16_c),
         TestMseParam(16, 16, &svt_aom_mse16x16_avx2, &svt_aom_mse16x16_c)));
 
+#endif
+
 class MseTestHighbd : public ::testing::TestWithParam<TestMseParamHighbd> {
   public:
     MseTestHighbd()
@@ -209,6 +213,8 @@ class MseTestHighbd : public ::testing::TestWithParam<TestMseParamHighbd> {
     MSE_HIGHBD_NXM_FUNC mse_ref_;
 };
 
+#ifdef ARCH_X86_64
+
 TEST_P(MseTestHighbd, MatchTest) {
     run_match_test();
 };
@@ -222,6 +228,8 @@ INSTANTIATE_TEST_SUITE_P(Variance, MseTestHighbd,
                              16, 16, &svt_aom_highbd_8_mse16x16_sse2,
                              &svt_aom_highbd_8_mse16x16_c)));
 
+#endif  // ARCH_X86_64
+
 // sum of squares test
 static uint32_t mb_ss_ref(const int16_t *src) {
     uint32_t res = 0;
@@ -280,6 +288,7 @@ class SumSquareTest : public ::testing::TestWithParam<SUM_SQUARE_FUNC> {
         }
     }
 };
+
 GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(SumSquareTest);
 
 TEST_P(SumSquareTest, ConstTest) {
@@ -401,6 +410,8 @@ TEST_P(VarianceTest, OneQuarterTest) {
     run_one_quarter_test();
 };
 
+#ifdef ARCH_X86_64
+
 INSTANTIATE_TEST_SUITE_P(
     Variance, VarianceTest,
     ::testing::Values(
@@ -503,6 +514,45 @@ INSTANTIATE_TEST_SUITE_P(
                                     &svt_aom_variance128x128_avx512)));
 #endif
 
+#endif  // ARCH_X86_64
+
+#ifdef ARCH_AARCH64
+
+INSTANTIATE_TEST_SUITE_P(
+    Variance_NEON, VarianceTest,
+    ::testing::Values(VarianceParam(16, 4, &svt_aom_variance16x4_c,
+                                    &svt_aom_variance16x4_neon),
+                      VarianceParam(16, 8, &svt_aom_variance16x8_c,
+                                    &svt_aom_variance16x8_neon),
+                      VarianceParam(16, 16, &svt_aom_variance16x16_c,
+                                    &svt_aom_variance16x16_neon),
+                      VarianceParam(16, 32, &svt_aom_variance16x32_c,
+                                    &svt_aom_variance16x32_neon),
+                      VarianceParam(16, 64, &svt_aom_variance16x64_c,
+                                    &svt_aom_variance16x64_neon),
+                      VarianceParam(32, 8, &svt_aom_variance32x8_c,
+                                    &svt_aom_variance32x8_neon),
+                      VarianceParam(32, 16, &svt_aom_variance32x16_c,
+                                    &svt_aom_variance32x16_neon),
+                      VarianceParam(32, 32, &svt_aom_variance32x32_c,
+                                    &svt_aom_variance32x32_neon),
+                      VarianceParam(32, 64, &svt_aom_variance32x64_c,
+                                    &svt_aom_variance32x64_neon),
+                      VarianceParam(64, 16, &svt_aom_variance64x16_c,
+                                    &svt_aom_variance64x16_neon),
+                      VarianceParam(64, 32, &svt_aom_variance64x32_c,
+                                    &svt_aom_variance64x32_neon),
+                      VarianceParam(64, 64, &svt_aom_variance64x64_c,
+                                    &svt_aom_variance64x64_neon),
+                      VarianceParam(64, 128, &svt_aom_variance64x128_c,
+                                    &svt_aom_variance64x128_neon),
+                      VarianceParam(128, 64, &svt_aom_variance128x64_c,
+                                    &svt_aom_variance128x64_neon),
+                      VarianceParam(128, 128, &svt_aom_variance128x128_c,
+                                    &svt_aom_variance128x128_neon)));
+
+#endif  // ARCH_AARCH64
+
 typedef unsigned int (*SubpixVarMxNFunc)(const uint8_t *a, int a_stride,
                                          int xoffset, int yoffset,
                                          const uint8_t *b, int b_stride,
@@ -639,6 +689,8 @@ void AvxSubpelVarianceTest::ExtremeRefTest() {
     }
 }
 
+#ifdef ARCH_X86_64
+
 const TestParams kArraySubpelVariance_sse2[] = {
     {7,
      7,
@@ -988,4 +1040,7 @@ TEST_P(AvxSubpelVarianceTest, Ref) {
 TEST_P(AvxSubpelVarianceTest, ExtremeRef) {
     ExtremeRefTest();
 }
+
+#endif  // ARCH_X86_64
+
 }  // namespace
